# Generated by roxygen2: do not edit by hand

export(aa_config)
export(eval_fork)
export(eval_safe)
export(exec_background)
export(exec_internal)
export(exec_status)
export(exec_wait)
export(r_background)
export(r_internal)
export(r_wait)
export(sys_config)
export(windows_quote)
importFrom(grDevices,graphics.off)
importFrom(grDevices,pdf)
useDynLib(sys,C_execute)
useDynLib(sys,R_aa_change_profile)
useDynLib(sys,R_aa_getcon)
useDynLib(sys,R_aa_is_enabled)
useDynLib(sys,R_eval_fork)
useDynLib(sys,R_exec_status)
useDynLib(sys,R_freeze)
useDynLib(sys,R_have_apparmor)
useDynLib(sys,R_safe_build)
useDynLib(sys,R_set_interactive)
useDynLib(sys,R_set_priority)
useDynLib(sys,R_set_rlimits)
useDynLib(sys,R_set_tempdir)
useDynLib(sys,R_setgid)
useDynLib(sys,R_setuid)
